@@ -43,21 +43,12 @@ class LimiterHandler(BaseHandler):
     def post(self):
         access_token = self.request.headers.get('X-AUTH-HOLMES', None)
 
-        if access_token is None:
-            self.set_status(403)
-            self.write_json({'reason': 'Empty access token'})
+        if self.is_empty_access_token(access_token):
             return
 
-        result = yield User.authenticate(
-            access_token,
-            self.application.http_client.fetch,
-            self.db,
-            self.application.config
-        )
+        result = yield User.authenticate(access_token, self.application)
 
-        if result and result.get('user', None) is None:
-            self.set_status(401)
-            self.write_json({'reason': 'Unauthorized user'})
+        if self.is_unauthorized_user(result):
             return
 
         post_data = loads(self.request.body)
@@ -67,7 +58,7 @@ class LimiterHandler(BaseHandler):
 
         if not url and not value:
             self.set_status(400)
-            self.write_json({'reason': 'Not url or value'})
+            self.write_json({'reason': 'Not url or value', 'description': self._('Not url or value')})
             return
 
         result = Limiter.add_or_update_limiter(self.db, url, value)
@@ -80,33 +71,24 @@ class LimiterHandler(BaseHandler):
     def delete(self, limiter_id=None):
         if not limiter_id:
             self.set_status(400)
-            self.write_json({'reason': 'Invalid data'})
+            self.write_json({'reason': 'Invalid data', 'description': self._('Invalid data')})
             return
 
         access_token = self.request.headers.get('X-AUTH-HOLMES', None)
 
-        if access_token is None:
-            self.set_status(403)
-            self.write_json({'reason': 'Empty access token'})
+        if self.is_empty_access_token(access_token):
             return
 
-        result = yield User.authenticate(
-            access_token,
-            self.application.http_client.fetch,
-            self.db,
-            self.application.config
-        )
+        result = yield User.authenticate(access_token, self.application)
 
-        if result and result.get('user', None) is None:
-            self.set_status(401)
-            self.write_json({'reason': 'Unauthorized user'})
+        if self.is_unauthorized_user(result):
             return
 
         limiter = Limiter.by_id(limiter_id, self.db)
 
         if not limiter or not limiter.id:
             self.set_status(404)
-            self.write_json({'reason': 'Not Found'})
+            self.write_json({'reason': 'Not Found', 'description': self._('Not Found')})
             return
 
         Limiter.delete(limiter.id, self.db)
