@@ -41,7 +41,9 @@ class PageHandler(BaseHandler):
             self.application.http_client.fetch,
             self.application.event_bus.publish,
             self.application.config,
-            self.application.girl
+            self.application.girl,
+            self.application.default_violations_values,
+            self.application.violation_definitions
         )
 
         created, url, result = result
@@ -57,7 +59,7 @@ class PageHandler(BaseHandler):
             return
 
         if not created and result['reason'] == 'redirect':
-            self.set_status(400, self._('Redirect URL [%s]') % url)
+            self.set_status(400, self._('Supplied URL is a redirect [%s]') % url)
             self.write_json({
                 'reason': 'redirect',
                 'url': url,
@@ -65,6 +67,8 @@ class PageHandler(BaseHandler):
             })
             return
 
+        yield self.application.cache.add_next_job_bucket(result, url)
+
         self.write(str(result))
         self.finish()
 
