@@ -29,15 +29,17 @@ class Violation(Base):
     def __repr__(self):
         return str(self)
 
-    def to_dict(self, violation_definitions):
+    def to_dict(self, violation_definitions, _):
         definition = violation_definitions.get(self.key.name, {})
 
+        value = definition.get('value_parser', lambda val: val)(self.value)
+        description = _(definition.get('description', '%s'))
         return {
             'key': self.key.name,
-            'title': definition.get('title', 'undefined'),
-            'description': definition.get('description', lambda value: value)(self.value),
+            'title': _(definition.get('title', _('undefined'))),
+            'description': (description % value) if value else description,
             'points': self.points,
-            'category': definition.get('category', 'undefined')
+            'category': _(definition.get('category', _('undefined')))
         }
 
     @classmethod
@@ -62,21 +64,6 @@ class Violation(Base):
             .group_by(sample.columns.key_id) \
             .order_by('count desc').all()
 
-    @classmethod
-    def get_most_common_violations(cls, db, violation_definitions, sample_limit=50000):
-        violations = []
-
-        for key_name, count in cls.get_most_common_violations_names(db, sample_limit):
-            definition = violation_definitions.get(key_name, {})
-            violations.append({
-                "key": key_name,
-                "title": definition.get('title', 'undefined'),
-                "category": definition.get('category', 'undefined'),
-                "count": count
-            })
-
-        return violations
-
     @classmethod
     def get_by_key_id_group_by_domain(cls, db, key_id):
 
