@@ -1,12 +1,11 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import logging
-
 from cow.server import Server
 from cow.plugins.sqlalchemy_plugin import SQLAlchemyPlugin
-from cow.plugins.redis_plugin import RedisPlugin, CowRedisClient
+from cow.plugins.redis_plugin import RedisPlugin
 from tornado.httpclient import AsyncHTTPClient
+import tornado.locale
 #from toredis import Client
 import redis
 from materialgirl import Materializer
@@ -37,12 +36,14 @@ from holmes.handlers.request import (
     LastRequestsStatusCodeHandler
 )
 from holmes.handlers.limiter import LimiterHandler
+from holmes.handlers.domains_violations_prefs import (
+    DomainsViolationsPrefsHandler
+)
 
 from holmes.handlers.bus import EventBusHandler
-from holmes.event_bus import EventBus, NoOpEventBus
-from holmes.utils import load_classes
-from holmes.models import Key
-from holmes.models import KeysCategory
+from holmes.event_bus import EventBus
+from holmes.utils import load_classes, load_languages, locale_path
+from holmes.models import Key, DomainsViolationsPrefs
 from holmes.cache import Cache
 from holmes import __version__
 from holmes.handlers import BaseHandler
@@ -98,6 +99,7 @@ class HolmesApiServer(Server):
             ('/domains-details/?', DomainsFullDataHandler),
             ('/domains/(%s)/?' % domain_regex, DomainDetailsHandler),
             ('/domains/(%s)/violations-per-day/?' % domain_regex, DomainViolationsPerDayHandler),
+            ('/domains/(%s)/violations-prefs/?' % domain_regex, DomainsViolationsPrefsHandler),
             ('/domains/(%s)/violations/?' % domain_regex, DomainGroupedViolationsHandler),
             ('/domains/(%s)/violations/(%s)/?' % (domain_regex, numbers_regex), DomainTopCategoryViolationsHandler),
             ('/domains/(%s)/reviews/?' % domain_regex, DomainReviewsHandler),
@@ -135,32 +137,62 @@ class HolmesApiServer(Server):
             from sqltap import sqltap
             self.sqltap = sqltap.start()
 
+        authnz_wrapper_class = self._load_authnz_wrapper()
+        if authnz_wrapper_class:
+            self.application.authnz_wrapper = authnz_wrapper_class(self.application.config)
+        else:
+            self.application.authnz_wrapper = None
+
         self.application.facters = self._load_facters()
         self.application.validators = self._load_validators()
         self.application.error_handlers = [handler(self.application.config) for handler in self._load_error_handlers()]
-        self.application.search_provider = self._load_search_provider()(self.application.config, self.application.db, io_loop)
+
+        self.application.search_provider = self._load_search_provider()(
+            config=self.application.config,
+            db=self.application.db,
+            authnz_wrapper=self.application.authnz_wrapper,
+            io_loop=io_loop
+        )
 
         self.application.fact_definitions = {}
         self.application.violation_definitions = {}
 
+        self.application.default_violations_values = {}
+
         for facter in self.application.facters:
             self.application.fact_definitions.update(facter.get_fact_definitions())
 
-        self._insert_keys(self.application.fact_definitions)
+        Key.insert_keys(self.application.db, self.application.fact_definitions)
 
         for validator in self.application.validators:
             self.application.violation_definitions.update(validator.get_violation_definitions())
 
-        self._insert_keys(self.application.violation_definitions)
+            self.application.default_violations_values.update(
+                validator.get_default_violations_values(self.application.config)
+            )
 
-        self.application.event_bus = NoOpEventBus(self.application)
+        Key.insert_keys(
+            self.application.db,
+            self.application.violation_definitions,
+            self.application.default_violations_values
+        )
+
+        self.application.event_bus = EventBus(self.application)
         self.application.http_client = AsyncHTTPClient(io_loop=io_loop)
-        self.connect_pub_sub(io_loop)
 
         self.application.cache = Cache(self.application)
 
         self.configure_material_girl()
 
+        self.configure_i18n()
+
+        DomainsViolationsPrefs.insert_default_violations_values_for_all_domains(
+            self.application.db,
+            self.application.default_violations_values,
+            self.application.violation_definitions,
+            self.application.cache
+        )
+
     def configure_material_girl(self):
         from holmes.material import configure_materials
 
@@ -173,27 +205,6 @@ class HolmesApiServer(Server):
 
         configure_materials(self.application.girl, self.application.db, self.config)
 
-    def _insert_key_category(self, key, name):
-        category = KeysCategory.get_or_create(self.application.db, name)
-        self.application.db.add(category)
-        self.application.db.flush()
-        self.application.db.commit()
-        return category
-
-    def _insert_keys(self, keys):
-        for name in keys.keys():
-            key = Key.get_or_create(self.application.db, name)
-            keys[name]['key'] = key
-
-            category_name = keys[name].get('category', None)
-            if category_name:
-                category = self._insert_key_category(key, category_name)
-                key.category = category
-
-            self.application.db.add(key)
-            self.application.db.flush()
-            self.application.db.commit()
-
     def _load_validators(self):
         return load_classes(default=self.config.VALIDATORS)
 
@@ -203,6 +214,14 @@ class HolmesApiServer(Server):
     def _load_error_handlers(self):
         return load_classes(default=self.config.ERROR_HANDLERS)
 
+    def _load_authnz_wrapper(self):
+        authnz_wrapper_class_name = self.config.get('AUTHNZ_WRAPPER', None)
+        if authnz_wrapper_class_name:
+            authnz_wrapper_list = load_classes(default=[authnz_wrapper_class_name])
+            if isinstance(authnz_wrapper_list, list) and len(authnz_wrapper_list) == 1:
+                return authnz_wrapper_list.pop()
+        return None
+
     def _load_search_provider(self):
         search_provider = load_classes(default=[self.config.SEARCH_PROVIDER])
         if isinstance(search_provider, list) and len(search_provider) == 1:
@@ -219,31 +238,9 @@ class HolmesApiServer(Server):
             statistics = self.sqltap.collect()
             sqltap.report(statistics, "report.html")
 
-    def connect_pub_sub(self, io_loop):
-        host = self.application.config.get('REDISHOST')
-        port = self.application.config.get('REDISPORT')
-
-        logging.info("Connecting pubsub to redis at %s:%d" % (host, port))
-
-        self.application.redis_pub_sub = CowRedisClient(io_loop=io_loop)
-        self.application.redis_pub_sub.authenticated = False
-        self.application.redis_pub_sub.connect(host, port, callback=self.has_connected(self.application))
-
-    def has_connected(self, application):
-        def handle(*args, **kw):
-            password = application.config.get('REDISPASS', None)
-            if password:
-                application.redis_pub_sub.auth(password, callback=self.handle_authenticated(application))
-            else:
-                self.handle_authenticated(application)()
-        return handle
-
-    def handle_authenticated(self, application):
-        def handle(*args, **kw):
-            application.redis_pub_sub.authenticated = True
-            application.event_bus = EventBus(self.application)  # can now connect to redis using pubsub
-
-        return handle
+    def configure_i18n(self):
+        load_languages()
+        tornado.locale.load_gettext_translations(locale_path, 'api')
 
 if __name__ == '__main__':
     main()
