@@ -1,7 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
+import os
+from os.path import abspath, join, dirname
 import logging
+import gettext
 
 try:
     from tornado import httputil
@@ -12,6 +15,25 @@ except ImportError:
 
 EMPTY_DOMAIN_RESULT = ('', '')
 
+locale_path = abspath(join(dirname(__file__), 'i18n/locale/'))
+languages = {}
+
+def _(message):
+    return message
+
+def load_languages():
+    global languages
+
+    for language in os.listdir(locale_path):
+        languages[language] = gettext.translation('api', locale_path, languages=[language])
+
+def install_i18n(language="en_US"):
+    global languages
+
+    english = languages.get("en_US")
+    lang = languages.get(language, english)
+    return lang.ugettext
+
 
 def get_domain_from_url(url, default_scheme='http'):
     if not url:
@@ -105,8 +127,3 @@ def count_url_levels(url):
             path = path[1:]
         return len(path.split('/'))
     return None
-
-def url_ends_with_slash(url):
-    if url.endswith('/'):
-        return url[:-1]
-    return url
